@@ -1,6 +1,6 @@
 /**
  *
- * $Header: /cvsroot/lesstif/lesstif/include/Motif-2.1/Xm/Xm.h.in,v 1.33 2002/09/10 22:09:13 dannybackx Exp $
+ * $Header: /cvsroot/lesstif/lesstif/include/Motif-2.1/Xm/Xm.h.in,v 1.34 2004/06/07 20:01:53 dannybackx Exp $
  *
  * Copyright  1995 Free Software Foundation, Inc.
  * Copyright  1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002 LessTif Development Team
@@ -29,6 +29,19 @@
 
 #include <stddef.h>    /* for  wchar_t, etc. */
 
+#if defined(_MFC_VER) && !defined(STATIC_XM)
+/* If Lesstif is built as a DLL with a Microsoft compiler, we need to use the
+ *	__declspec mechanism to import and export variables and functions.
+ */
+#if XMDLL	/* We're compiling the DLL */
+#define XMLIBEXPORT __declspec(dllexport)
+#else		/* We're including this in an application that will link to the DLL */
+#define XMLIBEXPORT __declspec(dllimport)
+#endif
+#else
+#define XMLIBEXPORT /* Nada */
+#endif
+
 #include <X11/Intrinsic.h>
 #include <X11/Shell.h>
 #include <X11/Xatom.h>
@@ -46,7 +59,7 @@
 #define LESSTIF_REVISION 93
 
 #define LesstifVersion (LESSTIF_VERSION * 1000 + LESSTIF_REVISION)
-#define LesstifVERSION_STRING "@(#)GNU/LessTif Version 2.1 Release 0.93.94"
+#define LesstifVERSION_STRING "@(#)GNU/LessTif Version 2.1 Release 0.93.96"
 
 /* since we're replacing Motif 2.1... */
 #define XmVERSION 2
@@ -67,7 +80,7 @@
 extern "C" {
 #endif
 
-extern int xmUseVersion;
+XMLIBEXPORT extern int xmUseVersion;
 
 /* pixmap stuff */
 
@@ -91,8 +104,8 @@ extern int xmUseVersion;
 #define XmDEFAULT_LIGHT_THRESHOLD       93
 #define XmDEFAULT_FOREGROUND_THRESHOLD  70
 
-extern char    _XmSDEFAULT_FONT[];
-extern char    _XmSDEFAULT_BACKGROUND[];
+XMLIBEXPORT extern char    _XmSDEFAULT_FONT[];
+XMLIBEXPORT extern char    _XmSDEFAULT_BACKGROUND[];
 
 typedef unsigned char XmDirection;
 
@@ -1256,119 +1269,119 @@ typedef struct _XmSecondaryResourceDataRec {
     Cardinal num_resources;
 } XmSecondaryResourceDataRec, *XmSecondaryResourceData;
 
-Cardinal XmGetSecondaryResourceData(WidgetClass wc,
+XMLIBEXPORT Cardinal XmGetSecondaryResourceData(WidgetClass wc,
 				    XmSecondaryResourceData **resData);
 
 /************************ Manager.c ***************************/
-Widget XmObjectAtPoint(Widget cw, Position x, Position y);
+XMLIBEXPORT Widget XmObjectAtPoint(Widget cw, Position x, Position y);
 
 /************************ ImageCache.c ***************************/
 
-Pixmap XmGetPixmap(Screen *screen, char *image_name,
+XMLIBEXPORT Pixmap XmGetPixmap(Screen *screen, char *image_name,
                    Pixel foreground, Pixel background);
-Pixmap XmGetPixmapByDepth(Screen *screen, char *image_name,
+XMLIBEXPORT Pixmap XmGetPixmapByDepth(Screen *screen, char *image_name,
                           Pixel foreground, Pixel background, int depth);
-Boolean XmDestroyPixmap(Screen *screen, Pixmap pixmap);
-Boolean XmInstallImage(XImage *image, char *image_name);
-Boolean XmUninstallImage(XImage *image);
-XtEnum XmGetScaledPixmap(Widget widget, String image_name,
+XMLIBEXPORT Boolean XmDestroyPixmap(Screen *screen, Pixmap pixmap);
+XMLIBEXPORT Boolean XmInstallImage(XImage *image, char *image_name);
+XMLIBEXPORT Boolean XmUninstallImage(XImage *image);
+XMLIBEXPORT XtEnum XmGetScaledPixmap(Widget widget, String image_name,
                          Pixel foreground, Pixel background,
                          int depth, double scaling_ratio);
 
 /************************** Manager.c *****************************/
 
-void XmUpdateDisplay(Widget w);
+XMLIBEXPORT void XmUpdateDisplay(Widget w);
 
 /************************* Primitive.c ****************************/
 
 typedef long XmOffset;
 typedef XmOffset *XmOffsetPtr;
 
-void XmResolvePartOffsets(WidgetClass w_class, XmOffsetPtr *offset);
-void XmResolveAllPartOffsets(WidgetClass w_class, XmOffsetPtr *offset,
+XMLIBEXPORT void XmResolvePartOffsets(WidgetClass w_class, XmOffsetPtr *offset);
+XMLIBEXPORT void XmResolveAllPartOffsets(WidgetClass w_class, XmOffsetPtr *offset,
 			     XmOffsetPtr *constraint_offset);
-Boolean XmWidgetGetBaselines(Widget wid, Dimension **baselines,
+XMLIBEXPORT Boolean XmWidgetGetBaselines(Widget wid, Dimension **baselines,
 			     int *line_count);
-Boolean XmWidgetGetDisplayRect(Widget wid, XRectangle *displayrect);
+XMLIBEXPORT Boolean XmWidgetGetDisplayRect(Widget wid, XRectangle *displayrect);
 
 /************************** RenderTable.c ****************************/
 
-XmRenderTable XmRenderTableAddRenditions(XmRenderTable        oldtable,
+XMLIBEXPORT XmRenderTable XmRenderTableAddRenditions(XmRenderTable        oldtable,
 					 XmRendition    *renditions,
 					 Cardinal       rendition_count,
 					 XmMergeMode    merge_mode);
 
-XmRenderTable XmRenderTableCopy(XmRenderTable table,
+XMLIBEXPORT XmRenderTable XmRenderTableCopy(XmRenderTable table,
 				XmStringTag     *tags,
 				int             tag_count);
 
-XmRenderTable XmRenderTableCvtFromProp(Widget         widget,
+XMLIBEXPORT XmRenderTable XmRenderTableCvtFromProp(Widget         widget,
 				       char             *property,
 				       unsigned int     length);
 
-unsigned int XmRenderTableCvtToProp(Widget            widget,
+XMLIBEXPORT unsigned int XmRenderTableCvtToProp(Widget            widget,
 				    XmRenderTable       table,
 				    char                **prop_return);
 
-void XmRenderTableFree(XmRenderTable table);
+XMLIBEXPORT void XmRenderTableFree(XmRenderTable table);
 
-XmRendition XmRenderTableGetRendition(XmRenderTable   table,
+XMLIBEXPORT XmRendition XmRenderTableGetRendition(XmRenderTable   table,
 				      XmStringTag       tag);
 
-XmRendition *XmRenderTableGetRenditions(XmRenderTable table,
+XMLIBEXPORT XmRendition *XmRenderTableGetRenditions(XmRenderTable table,
 					XmStringTag     *tags,
 					Cardinal        tag_count);
 
-int XmRenderTableGetTags(XmRenderTable        table,
+XMLIBEXPORT int XmRenderTableGetTags(XmRenderTable        table,
 			 XmStringTag    **tag_list);
 
-XmRenderTable XmRenderTableRemoveRenditions(XmRenderTable     oldtable,
+XMLIBEXPORT XmRenderTable XmRenderTableRemoveRenditions(XmRenderTable     oldtable,
 					    XmStringTag *tags,
 					    int         tag_count);
 
-Boolean XmeRenderTableGetDefaultFont(XmRenderTable    renderTable,
+XMLIBEXPORT Boolean XmeRenderTableGetDefaultFont(XmRenderTable    renderTable,
 				     XFontStruct        **fontStruct);
 
-XmString XmStringGenerate(XtPointer   text,
+XMLIBEXPORT XmString XmStringGenerate(XtPointer   text,
 			  XmStringTag   tag,
 			  XmTextType    type,
 			  XmStringTag   rendition);
   
-XmRendition XmRenditionCreate(Widget widget,
+XMLIBEXPORT XmRendition XmRenditionCreate(Widget widget,
 			      XmStringTag tag,
 			      ArgList arglist,
 			      Cardinal argcount);
   
-void XmRenditionFree(XmRendition rendition);
+XMLIBEXPORT void XmRenditionFree(XmRendition rendition);
 
-void XmRenditionUpdate(XmRendition rendition, 
+XMLIBEXPORT void XmRenditionUpdate(XmRendition rendition, 
 		       ArgList arglist, 
 		       Cardinal argcount);
 
-void XmRenditionRetrieve (XmRendition rendition,
+XMLIBEXPORT void XmRenditionRetrieve (XmRendition rendition,
                           ArgList arglist,
 			  Cardinal argcount);
 
 /************************ ResConvert.c ****************************/
 
-void XmRegisterConverters(void);
-void XmCvtStringToUnitType(XrmValuePtr args, Cardinal *num_args, XrmValue *from_val, XrmValue *to_val);
-char *XmRegisterSegmentEncoding(char *fontlist_tag, char *ct_encoding);
-char *XmMapSegmentEncoding(char *fontlist_tag);
-XmString XmCvtCTToXmString(char *text);
-Boolean XmCvtTextToXmString(Display *display, XrmValuePtr args,
+XMLIBEXPORT void XmRegisterConverters(void);
+XMLIBEXPORT void XmCvtStringToUnitType(XrmValuePtr args, Cardinal *num_args, XrmValue *from_val, XrmValue *to_val);
+XMLIBEXPORT char *XmRegisterSegmentEncoding(char *fontlist_tag, char *ct_encoding);
+XMLIBEXPORT char *XmMapSegmentEncoding(char *fontlist_tag);
+XMLIBEXPORT XmString XmCvtCTToXmString(char *text);
+XMLIBEXPORT Boolean XmCvtTextToXmString(Display *display, XrmValuePtr args,
 			    Cardinal *num_args, XrmValue *from_val,
 			    XrmValue *to_val, XtPointer *converter_data);
-char *XmCvtXmStringToCT(XmString string);
-Boolean XmCvtXmStringToText(Display *display, XrmValuePtr args,
+XMLIBEXPORT char *XmCvtXmStringToCT(XmString string);
+XMLIBEXPORT Boolean XmCvtXmStringToText(Display *display, XrmValuePtr args,
 			    Cardinal *num_args, XrmValue *from_val,
 			    XrmValue *to_val, XtPointer *converter_data);
-int XmConvertStringToUnits(Screen *screen, String spec, int orientation,
+XMLIBEXPORT int XmConvertStringToUnits(Screen *screen, String spec, int orientation,
 	int to_type, XtEnum *parse_error);
-unsigned int XmCvtXmStringToByteStream(XmString string,
+XMLIBEXPORT unsigned int XmCvtXmStringToByteStream(XmString string,
                                        unsigned char **prop_return);
-XmString XmCvtByteStreamToXmString(unsigned char *property);
-int XmCvtXmStringTableToTextProperty (Display *display,
+XMLIBEXPORT XmString XmCvtByteStreamToXmString(unsigned char *property);
+XMLIBEXPORT int XmCvtXmStringTableToTextProperty (Display *display,
                                       XmStringTable string_table,
                                       int count,
                                       XmICCEncodingStyle style,
@@ -1376,60 +1389,60 @@ int XmCvtXmStringTableToTextProperty (Display *display,
 
 /************************** ResInd.c ******************************/
 
-int XmConvertUnits(Widget widget, int orientation,
+XMLIBEXPORT int XmConvertUnits(Widget widget, int orientation,
 		   int from_unit_type, int from_value, int to_unit_type);
-int  XmCvtToHorizontalPixels(Screen *screen, int from_val, int from_type);
-int  XmCvtToVerticalPixels(Screen *screen, int from_val, int from_type);
-int  XmCvtFromHorizontalPixels(Screen *screen, int from_val, int to_type);
-int  XmCvtFromVerticalPixels(Screen *screen, int from_val, int to_type);
-void XmSetFontUnits(Display *display, int h_value, int v_value);
-void XmSetFontUnit(Display *display, int value);
+XMLIBEXPORT int  XmCvtToHorizontalPixels(Screen *screen, int from_val, int from_type);
+XMLIBEXPORT int  XmCvtToVerticalPixels(Screen *screen, int from_val, int from_type);
+XMLIBEXPORT int  XmCvtFromHorizontalPixels(Screen *screen, int from_val, int to_type);
+XMLIBEXPORT int  XmCvtFromVerticalPixels(Screen *screen, int from_val, int to_type);
+XMLIBEXPORT void XmSetFontUnits(Display *display, int h_value, int v_value);
+XMLIBEXPORT void XmSetFontUnit(Display *display, int value);
 
 /************************* MenuUtil.c *****************************/
 
-void XmSetMenuCursor(Display *display, Cursor cursorId);
-Cursor XmGetMenuCursor(Display *display);
+XMLIBEXPORT void XmSetMenuCursor(Display *display, Cursor cursorId);
+XMLIBEXPORT Cursor XmGetMenuCursor(Display *display);
 
 /************************** Simple.c ******************************/
 
-Widget XmCreateSimpleCheckBox(Widget parent, char *name,
+XMLIBEXPORT Widget XmCreateSimpleCheckBox(Widget parent, char *name,
 			      Arg *arglist, Cardinal argcount);
-Widget XmCreateSimpleMenuBar(Widget parent, char *name,
+XMLIBEXPORT Widget XmCreateSimpleMenuBar(Widget parent, char *name,
 			     Arg *arglist, Cardinal argcount);
-Widget XmCreateSimpleOptionMenu(Widget parent, char *name,
+XMLIBEXPORT Widget XmCreateSimpleOptionMenu(Widget parent, char *name,
 				Arg *arglist, Cardinal argcount);
-Widget XmCreateSimplePopupMenu(Widget parent, char *name,
+XMLIBEXPORT Widget XmCreateSimplePopupMenu(Widget parent, char *name,
 			       Arg *arglist, Cardinal argcount);
-Widget XmCreateSimplePulldownMenu(Widget parent, char *name,
+XMLIBEXPORT Widget XmCreateSimplePulldownMenu(Widget parent, char *name,
 				  Arg *arglist, Cardinal argcount);
-Widget XmCreateSimpleRadioBox(Widget parent, char *name,
+XMLIBEXPORT Widget XmCreateSimpleRadioBox(Widget parent, char *name,
 			      Arg *arglist, Cardinal argcount);
 
 /************************* VaSimple.c *****************************/
 
-Widget XmVaCreateSimpleCheckBox(Widget parent, String name,
+XMLIBEXPORT Widget XmVaCreateSimpleCheckBox(Widget parent, String name,
 				XtCallbackProc callback, ...);
-Widget XmVaCreateSimpleMenuBar(Widget parent, String name,
+XMLIBEXPORT Widget XmVaCreateSimpleMenuBar(Widget parent, String name,
 			       ...);
-Widget XmVaCreateSimpleOptionMenu(Widget parent, String name,
+XMLIBEXPORT Widget XmVaCreateSimpleOptionMenu(Widget parent, String name,
 				  XmString option_label,
 				  KeySym option_mnemonic,
 				  int button_set,
 				  XtCallbackProc callback, ...);
-Widget XmVaCreateSimplePopupMenu(Widget parent, String name,
+XMLIBEXPORT Widget XmVaCreateSimplePopupMenu(Widget parent, String name,
 				 XtCallbackProc callback, ...);
-Widget XmVaCreateSimplePulldownMenu(Widget parent, String name,
+XMLIBEXPORT Widget XmVaCreateSimplePulldownMenu(Widget parent, String name,
 				    int post_from_button,
 				    XtCallbackProc callback, ...);
-Widget XmVaCreateSimpleRadioBox(Widget parent, String name,
+XMLIBEXPORT Widget XmVaCreateSimpleRadioBox(Widget parent, String name,
 				int button_set,
 				XtCallbackProc callback, ...);
 
 /************************** TrackLoc.c *****************************/
 
-Widget XmTrackingEvent(Widget widget, Cursor cursor, Boolean confine_to,
+XMLIBEXPORT Widget XmTrackingEvent(Widget widget, Cursor cursor, Boolean confine_to,
 		       XEvent *event_return);
-Widget XmTrackingLocate(Widget widget, Cursor cursor, Boolean confine_to);
+XMLIBEXPORT Widget XmTrackingLocate(Widget widget, Cursor cursor, Boolean confine_to);
 
 /**************************** Visual.c *****************************/
 
@@ -1437,28 +1450,28 @@ typedef void (*XmColorProc)(XColor *bg_color, XColor *fg_color,
 			    XColor *sel_color, XColor *ts_color, XColor *bs_color);
 
 
-XmColorProc XmSetColorCalculation(XmColorProc proc);
-XmColorProc XmGetColorCalculation(void);
-void XmGetColors(Screen *screen, Colormap color_map,
+XMLIBEXPORT XmColorProc XmSetColorCalculation(XmColorProc proc);
+XMLIBEXPORT XmColorProc XmGetColorCalculation(void);
+XMLIBEXPORT void XmGetColors(Screen *screen, Colormap color_map,
 			Pixel background, Pixel *foreground_ret,
 			Pixel *top_shadow_ret, Pixel *bottom_shadow_ret,
 			Pixel *select_ret);
-void XmChangeColor(Widget widget, Pixel background);
+XMLIBEXPORT void XmChangeColor(Widget widget, Pixel background);
 
 /*************************** XmString.c ****************************/
 
-Dimension XmStringBaseline(XmFontList fontlist, XmString string);
-Boolean XmStringByteCompare(XmString s1, XmString s2);
-Boolean XmStringCompare(XmString s1, XmString s2);
-XmString XmStringConcat(XmString s1, XmString s2);
-XmString XmStringConcatAndFree(XmString s1, XmString s2);
-XmString XmStringCreate(char *text, char *tag);
-XmString XmStringCreateLtoR(char *text, char *tag);
-XmString XmStringLtoRCreate(char *text, char *tag);
-XmString XmStringCreateLocalized(char *text);
-XmString XmStringCreateSimple(char *text);
-XmString XmStringDirectionCreate(XmStringDirection direction);
-void XmStringDraw(Display *d, 
+XMLIBEXPORT Dimension XmStringBaseline(XmFontList fontlist, XmString string);
+XMLIBEXPORT Boolean XmStringByteCompare(XmString s1, XmString s2);
+XMLIBEXPORT Boolean XmStringCompare(XmString s1, XmString s2);
+XMLIBEXPORT XmString XmStringConcat(XmString s1, XmString s2);
+XMLIBEXPORT XmString XmStringConcatAndFree(XmString s1, XmString s2);
+XMLIBEXPORT XmString XmStringCreate(char *text, char *tag);
+XMLIBEXPORT XmString XmStringCreateLtoR(char *text, char *tag);
+XMLIBEXPORT XmString XmStringLtoRCreate(char *text, char *tag);
+XMLIBEXPORT XmString XmStringCreateLocalized(char *text);
+XMLIBEXPORT XmString XmStringCreateSimple(char *text);
+XMLIBEXPORT XmString XmStringDirectionCreate(XmStringDirection direction);
+XMLIBEXPORT void XmStringDraw(Display *d, 
 		  Window w,
 		  XmFontList fontlist,
 		  XmString string,
@@ -1469,7 +1482,7 @@ void XmStringDraw(Display *d,
 		  unsigned char alignment,
 		  unsigned char layout_direction,
 		  XRectangle *clip);
-void XmStringDrawImage(Display *d, Window w,
+XMLIBEXPORT void XmStringDrawImage(Display *d, Window w,
 		       XmFontList fontlist,
 		       XmString string,
 		       GC gc,
@@ -1479,54 +1492,54 @@ void XmStringDrawImage(Display *d, Window w,
 		       unsigned char alignment,
 		       unsigned char layout_direction,
 		       XRectangle *clip);
-void XmStringDrawUnderline(Display *d, Window w,
+XMLIBEXPORT void XmStringDrawUnderline(Display *d, Window w,
 			   XmFontList fontlist, XmString string,
 			   GC gc, Position x, Position y, Dimension width,
 			   unsigned char alignment,
 			   unsigned char layout_direction,
 			   XRectangle *clip,
 			   XmString underline);
-Boolean XmStringEmpty(XmString s1);
-void XmStringExtent(XmFontList fontlist, 
+XMLIBEXPORT Boolean XmStringEmpty(XmString s1);
+XMLIBEXPORT void XmStringExtent(XmFontList fontlist, 
 		    XmString string,
 		    Dimension *width,
 		    Dimension *height);
-void XmStringFree(XmString string);
-void XmStringFreeContext(XmStringContext context);
-Boolean XmStringGetLtoR(XmString string,
+XMLIBEXPORT void XmStringFree(XmString string);
+XMLIBEXPORT void XmStringFreeContext(XmStringContext context);
+XMLIBEXPORT Boolean XmStringGetLtoR(XmString string,
 			XmStringCharSet tag,
 			char **text);
-XmStringComponentType XmStringGetNextComponent(XmStringContext context,
+XMLIBEXPORT XmStringComponentType XmStringGetNextComponent(XmStringContext context,
 					       char **text,
 					       XmStringCharSet *tag,
 					       XmStringDirection *direction,
 					       XmStringComponentType *unknown_tag,
 					       unsigned short *unknown_length,
 					       unsigned char **unknown_value);
-Boolean XmStringGetNextSegment(XmStringContext context,
+XMLIBEXPORT Boolean XmStringGetNextSegment(XmStringContext context,
 			       char **text,
 			       XmStringCharSet *tag,
 			       XmStringDirection *direction,
 			       Boolean *separator);
-Boolean XmStringHasSubstring(XmString string,
+XMLIBEXPORT Boolean XmStringHasSubstring(XmString string,
 			     XmString substring);
-Dimension XmStringHeight(XmFontList fontlist, XmString string);
-Boolean XmStringInitContext(XmStringContext *context,
+XMLIBEXPORT Dimension XmStringHeight(XmFontList fontlist, XmString string);
+XMLIBEXPORT Boolean XmStringInitContext(XmStringContext *context,
 			    XmString string);
-int XmStringLength(XmString s1);
-int XmStringLineCount(XmString string);
-XmString XmStringNConcat(XmString s1, XmString s2, int num_bytes);
-XmString XmStringCopy(XmString s);
-XmString XmStringNCopy(XmString s1, int num_bytes);
-XmStringComponentType XmStringPeekNextComponent(XmStringContext context);
-XmString XmStringSegmentCreate(char *text, char *tag, 
+XMLIBEXPORT int XmStringLength(XmString s1);
+XMLIBEXPORT int XmStringLineCount(XmString string);
+XMLIBEXPORT XmString XmStringNConcat(XmString s1, XmString s2, int num_bytes);
+XMLIBEXPORT XmString XmStringCopy(XmString s);
+XMLIBEXPORT XmString XmStringNCopy(XmString s1, int num_bytes);
+XMLIBEXPORT XmStringComponentType XmStringPeekNextComponent(XmStringContext context);
+XMLIBEXPORT XmString XmStringSegmentCreate(char *text, char *tag, 
 			       XmStringDirection direction,
 			       Boolean separator);
-XmString XmStringSeparatorCreate(void);
+XMLIBEXPORT XmString XmStringSeparatorCreate(void);
 
-Dimension XmStringWidth(XmFontList fontList, XmString string);
+XMLIBEXPORT Dimension XmStringWidth(XmFontList fontList, XmString string);
 
-XtPointer XmStringUnparse(XmString string,
+XMLIBEXPORT XtPointer XmStringUnparse(XmString string,
                           XmStringTag tag,
                           XmTextType tag_type,
                           XmTextType output_type,
@@ -1535,15 +1548,15 @@ XtPointer XmStringUnparse(XmString string,
                           XmParseModel parse_model);
 
 
-Cardinal XmStringToXmStringTable(XmString string,
+XMLIBEXPORT Cardinal XmStringToXmStringTable(XmString string,
                                  XmString break_comp,
                                  XmStringTable *table);
 
-XmString XmStringTableToXmString(XmStringTable table,
+XMLIBEXPORT XmString XmStringTableToXmString(XmStringTable table,
                                  Cardinal count,
                                  XmString break_component);
 
-XtPointer *XmStringTableUnparse(XmStringTable table,
+XMLIBEXPORT XtPointer *XmStringTableUnparse(XmStringTable table,
                                 Cardinal count,
                                 XmStringTag tag,
                                 XmTextType tag_type,
@@ -1552,7 +1565,7 @@ XtPointer *XmStringTableUnparse(XmStringTable table,
                                 Cardinal parse_count,
                                 XmParseModel parse_model);
 
-XmStringTable XmStringTableParseStringArray(XtPointer *strings,
+XMLIBEXPORT XmStringTable XmStringTableParseStringArray(XtPointer *strings,
                                             Cardinal count,
                                             XmStringTag tag,
                                             XmTextType type,
@@ -1560,97 +1573,97 @@ XmStringTable XmStringTableParseStringArray(XtPointer *strings,
                                             Cardinal parse_count,
                                             XtPointer call_data);
 
-XmString XmStringPutRendition(XmString string,
+XMLIBEXPORT XmString XmStringPutRendition(XmString string,
                               XmStringTag rendition);
 
-XmParseMapping XmParseMappingCreate(ArgList arg_list,
+XMLIBEXPORT XmParseMapping XmParseMappingCreate(ArgList arg_list,
                                     Cardinal arg_count);
 
-void XmParseMappingSetValues(XmParseMapping parse_mapping,
+XMLIBEXPORT void XmParseMappingSetValues(XmParseMapping parse_mapping,
                              ArgList arg_list,
                              Cardinal arg_count);
 
-void XmParseMappingGetValues(XmParseMapping parse_mapping,
+XMLIBEXPORT void XmParseMappingGetValues(XmParseMapping parse_mapping,
                              ArgList arg_list,
                              Cardinal arg_count);
 
-void XmParseMappingFree(XmParseMapping parse_mapping);
+XMLIBEXPORT void XmParseMappingFree(XmParseMapping parse_mapping);
 
-void XmParseTableFree(XmParseTable parse_table,
+XMLIBEXPORT void XmParseTableFree(XmParseTable parse_table,
                       Cardinal parse_count);
 
-XmStringComponentType XmStringGetNextTriple(XmStringContext context,
+XMLIBEXPORT XmStringComponentType XmStringGetNextTriple(XmStringContext context,
                                             unsigned int *length,
                                             XtPointer *value);
 
-XmStringComponentType XmStringPeekNextTriple(XmStringContext context);
+XMLIBEXPORT XmStringComponentType XmStringPeekNextTriple(XmStringContext context);
 
-XmString XmStringComponentCreate(XmStringComponentType ctype,
+XMLIBEXPORT XmString XmStringComponentCreate(XmStringComponentType ctype,
                                  unsigned int length,
                                  XtPointer value);
 
-Boolean XmStringIsVoid(XmString s1);
+XMLIBEXPORT Boolean XmStringIsVoid(XmString s1);
 
-XmString XmStringParseText(XtPointer text, XtPointer *text_end, XmStringTag tag,
+XMLIBEXPORT XmString XmStringParseText(XtPointer text, XtPointer *text_end, XmStringTag tag,
 	XmTextType type, XmParseTable parse_table, Cardinal parse_count,
 	XtPointer call_data);
 
 /*************************** FontList.c *****************************/
 
-XmFontList XmFontListAppendEntry(XmFontList oldlist,
+XMLIBEXPORT XmFontList XmFontListAppendEntry(XmFontList oldlist,
 				 XmFontListEntry entry);
-XmFontList XmFontListCreate(XFontStruct *font,
+XMLIBEXPORT XmFontList XmFontListCreate(XFontStruct *font,
 			    XmStringCharSet charset);
-XmFontList XmFontListAdd(XmFontList old,
+XMLIBEXPORT XmFontList XmFontListAdd(XmFontList old,
 			 XFontStruct *font,
 			 XmStringCharSet charset);
-XmFontList XmFontListCopy(XmFontList fontlist);
-XmFontListEntry XmFontListEntryCreate(char *tag,
+XMLIBEXPORT XmFontList XmFontListCopy(XmFontList fontlist);
+XMLIBEXPORT XmFontListEntry XmFontListEntryCreate(char *tag,
 				      XmFontType type,
 				      XtPointer font);
-void XmFontListEntryFree(XmFontListEntry *entry);
-XtPointer XmFontListEntryGetFont(XmFontListEntry entry,
+XMLIBEXPORT void XmFontListEntryFree(XmFontListEntry *entry);
+XMLIBEXPORT XtPointer XmFontListEntryGetFont(XmFontListEntry entry,
 				 XmFontType *type_return);
-char *XmFontListEntryGetTag(XmFontListEntry entry);
-XmFontListEntry XmFontListEntryLoad(Display *display,
+XMLIBEXPORT char *XmFontListEntryGetTag(XmFontListEntry entry);
+XMLIBEXPORT XmFontListEntry XmFontListEntryLoad(Display *display,
 				    char *font_name,
 				    XmFontType type,
 				    char *tag);
-void XmFontListFree(XmFontList list);
-void XmFontListFreeFontContext(XmFontContext context);
-Boolean XmFontListInitFontContext(XmFontContext *context,
+XMLIBEXPORT void XmFontListFree(XmFontList list);
+XMLIBEXPORT void XmFontListFreeFontContext(XmFontContext context);
+XMLIBEXPORT Boolean XmFontListInitFontContext(XmFontContext *context,
 				  XmFontList fontlist);
-XmFontListEntry XmFontListNextEntry(XmFontContext context);
-Boolean XmFontListGetNextFont(XmFontContext context, XmStringCharSet *charset, XFontStruct **font);
-XmFontList XmFontListRemoveEntry(XmFontList oldlist,
+XMLIBEXPORT XmFontListEntry XmFontListNextEntry(XmFontContext context);
+XMLIBEXPORT Boolean XmFontListGetNextFont(XmFontContext context, XmStringCharSet *charset, XFontStruct **font);
+XMLIBEXPORT XmFontList XmFontListRemoveEntry(XmFontList oldlist,
 				 XmFontListEntry entry);
 
-XmFontList XmStringCreateFontList( XFontStruct *font, XmStringCharSet charset);
+XMLIBEXPORT XmFontList XmStringCreateFontList( XFontStruct *font, XmStringCharSet charset);
 
 /************************** Dest.c ***********************************/
 
-Widget XmGetDestination(Display *display);
+XMLIBEXPORT Widget XmGetDestination(Display *display);
 
 /*************************** Traversal.c *****************************/
 
-Boolean XmIsTraversable(Widget widget);
-XmVisibility XmGetVisibility(Widget widget);
-void XmAddTabGroup(Widget widget);
-void XmRemoveTabGroup(Widget widget);
-Widget XmGetTabGroup(Widget widget);
-Boolean XmProcessTraversal(Widget widget, XmTraversalDirection direction);
-Widget XmGetFocusWidget(Widget widget);
+XMLIBEXPORT Boolean XmIsTraversable(Widget widget);
+XMLIBEXPORT XmVisibility XmGetVisibility(Widget widget);
+XMLIBEXPORT void XmAddTabGroup(Widget widget);
+XMLIBEXPORT void XmRemoveTabGroup(Widget widget);
+XMLIBEXPORT Widget XmGetTabGroup(Widget widget);
+XMLIBEXPORT Boolean XmProcessTraversal(Widget widget, XmTraversalDirection direction);
+XMLIBEXPORT Widget XmGetFocusWidget(Widget widget);
 
 /**************************** Direction.c *********************************/
 
-Boolean XmDirectionMatch(XmDirection dir1, XmDirection dir2);
-Boolean XmDirectionMatchPartial(XmDirection dir1, XmDirection dir2, XmDirection dir_mask);
-XmStringDirection XmDirectionToStringDirection(XmDirection dir);
-XmDirection XmStringDirectionToDirection(XmStringDirection sdir);
+XMLIBEXPORT Boolean XmDirectionMatch(XmDirection dir1, XmDirection dir2);
+XMLIBEXPORT Boolean XmDirectionMatchPartial(XmDirection dir1, XmDirection dir2, XmDirection dir_mask);
+XMLIBEXPORT XmStringDirection XmDirectionToStringDirection(XmDirection dir);
+XMLIBEXPORT XmDirection XmStringDirectionToDirection(XmStringDirection sdir);
 
 /******************************* Xme.c ************************************/
 
-void XmeConvertMerge(XtPointer data, Atom type,
+XMLIBEXPORT void XmeConvertMerge(XtPointer data, Atom type,
                      int format, unsigned long length,
                      XmConvertCallbackStruct *call_data);
 
